import svelte from 'rollup-plugin-svelte';
import resolve from '@rollup/plugin-node-resolve';
import commonjs from '@rollup/plugin-commonjs';
import livereload from 'rollup-plugin-livereload';
import replace from 'rollup-plugin-replace';
import { terser } from 'rollup-plugin-terser';
import sveltePreprocess from 'svelte-preprocess';
import builtins from 'rollup-plugin-node-builtins';
import globals from 'rollup-plugin-node-globals';
import strip from '@rollup/plugin-strip';

const production = !process.env.ROLLUP_WATCH;

const preprocess = sveltePreprocess({
  'scss': {
    'includePaths': ['src']
  },
  'postcss': {
    'plugins': [require('autoprefixer')]
  }
});

export default {
  'input': 'src/main.js',
  'output': {
    'sourcemap': (!production),
    'format': 'iife',
    'name': 'app',
    'file': 'public/build/bundle.js'
  },
  'plugins': [
    // globals(),
    // builtins(),
	  strip({
		  'debugger': !(production)
	  }),
    svelte({
      // enable run-time checks when not in production
      'dev': !production,
      preprocess,
      // we'll extract any component CSS out into
      // a separate file - better for performance
      'css': css => {
        css.write('public/build/bundle.css');
      }
    }),

    // If you have external dependencies installed from
    // npm, you'll most likely need these plugins. In
    // some cases you'll need additional configuration -
    // consult the documentation for details:
    // https://github.com/rollup/plugins/tree/master/packages/commonjs
    resolve({
      'browser': true,
      'dedupe': ['svelte']
    }),
    commonjs(),
    replace({
      'exclude': 'node_modules/**',
      'ENV': JSON.stringify(production ? 'production' : 'development')
    }),

    // In dev mode, call `npm run start` once
    // the bundle has been generated
    !production && serve(),

    // Watch the `public` directory and refresh the
    // browser on changes when not in production
    !production && livereload('public'),

    // If we're building for production (npm run build
    // instead of npm run dev), minify
    production && terser()
  ],
  'watch': {
    'clearScreen': false
  }
};

function serve() {
  let started = false;

  return {
    writeBundle() {
      if (!started) {
        started = true;

        require('child_process').spawn('npm', ['run', 'start', '--', '--dev'], {
          'stdio': ['ignore', 'inherit', 'inherit'],
          'shell': true
        });
      }
    }
  };
}
